@@ -43,7 +43,7 @@ typedef void (*pgut_atexit_callback)(bool fatal, void *userdata);
 extern const char  *PROGRAM_NAME;
 extern const char  *PROGRAM_VERSION;
 extern const char  *PROGRAM_URL;
-extern const char  *PROGRAM_EMAIL;
+extern const char  *PROGRAM_ISSUES;
 
 /*
  * pgut framework variables and functions
