@@ -29,20 +29,12 @@ termStringInfo(StringInfo str)
 static void
 appendStringInfoVA_s(StringInfo str, const char *fmt, va_list args)
 {
-#if PG_VERSION_NUM >= 90400
 	int needed;
 	while ((needed = appendStringInfoVA(str, fmt, args)) > 0)
 	{
 		/* Double the buffer size and try again. */
 		enlargeStringInfo(str, needed);
 	}
-#else
-	while (!appendStringInfoVA(str, fmt, args))
-	{
-		/* Double the buffer size and try again. */
-		enlargeStringInfo(str, str->maxlen);
-	}
-#endif
 }
 
 /* simple execute */
